@@ -7,7 +7,7 @@ BEGIN { require Fennec::Runner }
 use Fennec::Test;
 use Fennec::Util qw/inject_sub require_module verbose_message/;
 use Carp qw/croak carp/;
-our $VERSION = '2.013';
+our $VERSION = '2.017';
 
 sub defaults {
     (
@@ -19,7 +19,7 @@ sub defaults {
             'Mock::Quick',
             'Child',
         ],
-        parallel     => $ENV{'FENNEC_PARALLEL'} || 3,
+        parallel     => defined $ENV{'FENNEC_PARALLEL'} ? $ENV{'FENNEC_PARALLEL'} : 3,
         runner_class => 'Fennec::Runner',
         with_tests   => [],
         Child        => ['child'],
@@ -114,6 +114,14 @@ sub import {
         $runner_init,
     );
 
+    $class->after_import({
+        importer => $importer,
+        runner   => $runner,
+        meta     => $meta,
+        wf_meta  => $wfmeta,
+        layer    => $wfmeta->peek_layer || $wfmeta->root_layer,
+    }) if $class->can('after_import');
+
     verbose_message("Entering primary stage: $importer\n");
 }
 
